@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-04-18'; # DATE
-our $VERSION = '0.59'; # VERSION
+our $DATE = '2016-07-22'; # DATE
+our $VERSION = '0.60'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -35,14 +35,18 @@ sub _process_module {
     my ($self, $document, $input) = @_;
 
     my $filename = $input->{filename};
+    my ($file) = grep { $_->name eq $filename } @{ $input->{zilla}->files };
+
+    unless ($file->isa("Dist::Zilla::File::OnDisk")) {
+        $self->log_debug(["skipping %s: not an ondisk file, currently only ondisk files are processed", $filename]);
+        return;
+    }
 
     # guess package from filename
     $filename =~ m!^lib/(.+)\.pm$!;
     my $package = $1;
     $package =~ s!/!::!g;
 
-    # XXX handle dynamically generated module (if there is such thing in the
-    # future)
     local @INC = ("lib", @INC);
 
     my $url = $package; $url =~ s!::!/!g; $url = "pl:/$url/";
@@ -762,7 +766,7 @@ sub _process_script {
                 } else {
                     push @content, "L<$url>";
                 }
-                push @content, ", $link->{summary}" if $link->{summary};
+                push @content, ". $link->{summary}" if $link->{summary};
                 push @content, ". " .
                     Markdown::To::POD::markdown_to_pod($link->{description})
                       if $link->{description};
@@ -833,7 +837,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.59 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-04-18.
+This document describes version 0.60 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-07-22.
 
 =head1 SYNOPSIS
 
